@@ -85,6 +85,7 @@ const {
   normalizeEncoding,
   kIsEncodingSymbol,
   defineLazyProperties,
+  encodingsMap,
 } = require('internal/util');
 const {
   isAnyArrayBuffer,
@@ -95,7 +96,6 @@ const {
 const {
   inspect: utilInspect,
 } = require('internal/util/inspect');
-const { encodings } = internalBinding('string_decoder');
 
 const {
   codes: {
@@ -149,10 +149,6 @@ const constants = ObjectDefineProperties({}, {
 Buffer.poolSize = 8 * 1024;
 let poolSize, poolOffset, allocPool;
 
-const encodingsMap = { __proto__: null };
-for (let i = 0; i < encodings.length; ++i)
-  encodingsMap[encodings[i]] = i;
-
 function createPool() {
   poolSize = Buffer.poolSize;
   allocPool = createUnsafeBuffer(poolSize).buffer;
